@@ -304,6 +304,10 @@ def test_os_build_compare():
     assert not res
     res = utils.version_compare("1.15.0", 0, "*", None, "1.15.1-2ubuntu2.2")
     assert res
+    res = utils.version_compare("1:1.1.1k-7.el8_6", 0, "*", None, "1.1.1k")
+    assert not res
+    res = utils.version_compare("1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1-1ubuntu2.1")
+    assert not res
 
 
 def test_parse_uri():
@@ -358,3 +362,4 @@ def test_ubuntu_versions():
     assert utils.convert_to_semver("6.2.4.5.dfsg1-0.14ubuntu0.1")[0]
     assert utils.convert_to_semver("1.5.dfsg+1.5.0.13~prepatch070731-0ubuntu1")[0]
     assert utils.convert_to_semver("01.03.00.99.svn.300-3")[0]
+    assert utils.checkEpoch("1:1.1.1k-7.el8_6")
