@@ -52,19 +52,16 @@ class AquaSource(NvdSource):
 
     def download_all(self, local_store=True):
         """Download all cve data"""
+        # For performance do not retain the whole data in-memory
+        # See: https://github.com/AppThreat/vulnerability-db/issues/27
         data_list = []
-        data = self.fetch(config.aquasec_vuln_list_url)
-        if data:
-            if local_store:
-                self.store(data)
-            data_list += data
+        self.fetch(config.aquasec_vuln_list_url)
         return data_list
 
     def download_recent(self, local_store=True):
         raise NotImplementedError
 
     def _process_zip(self, zname):
-        ret_data = []
         with ZipFile(zname, "r") as zipfp:
             for zf in zipfp.namelist():
                 if self.is_supported_source(zf):
@@ -72,7 +69,8 @@ class AquaSource(NvdSource):
                         cve_data = jsonf.read()
                         try:
                             json_data = json_lib.loads(cve_data)
-                            ret_data += self.convert(json_data)
+                            ret_data = self.convert(json_data)
+                            self.store(ret_data, reindex=False)
                         except Exception as e:
                             pass
 
@@ -127,6 +125,14 @@ class AquaSource(NvdSource):
         ):
             if distro in zfname:
                 return False
+        nvd_start_year = 2018
+        try:
+            nvd_start_year = int(config.nvd_start_year)
+        except:
+            pass
+        for year in range(1999, nvd_start_year):
+            if f"CVE-{year}-" in zfname:
+                return False
         if zfname.endswith(".json"):
             return True
         return False
@@ -334,9 +340,18 @@ class AquaSource(NvdSource):
                 fix_version_start_excluding = ""
                 fix_version_end_excluding = ""
                 fix_version_start_including = ""
-                if status_obj.get("Status") in ("not-affected", "released"):
-                    fix_version_start_including = status_obj.get("Note")
-                    version_end_excluding = status_obj.get("Note")
+                fix_note = status_obj.get("Note")
+                if (
+                    status_obj.get("Status")
+                    in (
+                        "not-affected",
+                        "released",
+                    )
+                    and " " not in fix_note
+                    and "CVE" not in fix_note
+                ):
+                    fix_version_start_including = fix_note
+                    version_end_excluding = fix_note
                 if pkg_name and fix_version_start_including:
                     tdata = config.CVE_TPL % dict(
                         cve_id=cve_id,
