@@ -337,9 +337,11 @@ def checkEpoch(s):
     if not s:
         return False
     m = DEBIAN_VALID_VERSION.search(s)
-    if not m:
-        return False
-    return True if m.group("epoch") is not None else False
+    if m and m.group("epoch"):
+        return True
+    if ":" in s or "ubuntu" in s or "deb" in s or "mint" in s:
+        return True
+    return False
 
 
 def is_hash_mode(
@@ -374,6 +376,15 @@ def is_epoch_mode(
     )
 
 
+def trim_epoch_colon(s):
+    m = DEBIAN_VALID_VERSION.search(s)
+    if m and m.group("upstream_version"):
+        return m.group("upstream_version")
+    if ":" in s:
+        return s.split(":")[1].split("-")[0]
+    return s
+
+
 def trim_epoch(
     compare_ver,
     min_version,
@@ -382,20 +393,19 @@ def trim_epoch(
     max_affected_version_excluding,
 ):
     if checkEpoch(compare_ver):
-        m = DEBIAN_VALID_VERSION.search(compare_ver)
-        compare_ver = m.group("upstream_version")
+        compare_ver = trim_epoch_colon(compare_ver)
     if checkEpoch(min_version):
-        m = DEBIAN_VALID_VERSION.search(min_version)
-        min_version = m.group("upstream_version")
+        min_version = trim_epoch_colon(min_version)
     if checkEpoch(max_version):
-        m = DEBIAN_VALID_VERSION.search(max_version)
-        max_version = m.group("upstream_version")
+        max_version = trim_epoch_colon(max_version)
     if checkEpoch(min_affected_version_excluding):
-        m = DEBIAN_VALID_VERSION.search(min_affected_version_excluding)
-        min_affected_version_excluding = m.group("upstream_version")
+        min_affected_version_excluding = trim_epoch_colon(
+            min_affected_version_excluding
+        )
     if checkEpoch(max_affected_version_excluding):
-        m = DEBIAN_VALID_VERSION.search(max_affected_version_excluding)
-        max_affected_version_excluding = m.group("upstream_version")
+        max_affected_version_excluding = trim_epoch_colon(
+            max_affected_version_excluding
+        )
     return (
         compare_ver,
         min_version,
